@@ -22,8 +22,8 @@ def figsize(scale):
 
     return fig_size
 
-#import warnings
-#warnings.filterwarnings('ignore') 
+import warnings
+warnings.filterwarnings('ignore') 
 
 
 import matplotlib as mpl
@@ -90,7 +90,6 @@ def plot_eigvec_ani(Ruc, n_uc, k,eigvec,freq, ax, fig, masses):
     Rt = Ruc.flatten().reshape(len(EIGs),1) + np.real(ut)
     Rt2 = Ruc.flatten().reshape(len(EIGs),1) + np.imag(ut)
     
-    print(Rt[:,0])
 
     plot = ax.scatter(Rt[0::3,0], Rt[1::3,0], Rt[2::3,0], s=masses[0::3]*100)
     ax.quiver(*centroid, *k*L, color='red')
@@ -368,9 +367,13 @@ def plot_k2(f, data, data_projected, indexes,freqs, max_Z, branches,  freq_res,
     fig, ax = plt.subplots()
     
     if(len(branches) == tot_branches): #plot whole spectrum
+        if(max_Z > np.max(data) or max_Z < 0.0):
+            max_Z = np.max(data)
         print('Drawing the whole spectrum...')
         ax.contourf(X,Y,data,100, vmax=max_Z)
     else:
+        if(max_Z > np.max(data) or max_Z < 0.0):
+            max_Z = np.max(data_projected)
         print('Drawing branches ', branches)
         ax.contourf(X,Y,np.sum(data_projected[:,:,:], axis=1),100, vmax=max_Z)
     
